==> uui-loader-bar-0.0.4.tgz: package/lib/uui-loader-bar.element.js <==
import { css, LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import { styleMap } from 'lit/directives/style-map.js';

var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __decorateClass = (decorators, target, key, kind) => {
  var result = kind > 1 ? void 0 : kind ? __getOwnPropDesc(target, key) : target;
  for (var i = decorators.length - 1, decorator; i >= 0; i--)
    if (decorator = decorators[i])
      result = (kind ? decorator(target, key, result) : decorator(result)) || result;
  if (kind && result)
    __defProp(target, key, result);
  return result;
};
class UUILoaderBarElement extends LitElement {
  constructor() {
    super(...arguments);
    this.progress = 0;
    this.animationDuration = 1;
    this.hidden = false;
  }
  getProgressStyle() {
    return { maxWidth: `${this.progress}%` };
  }
  render() {
    return html`
      <div id="bar-container" class=${this.progress ? "" : "animate"}>
        <div
          id="bar"
          style=${this.progress ? styleMap(this.getProgressStyle()) : ""}></div>
        <div
          id="bar-anim"
          style="animation-duration: ${this.animationDuration}s"></div>
        <div id="bar-background"></div>
      </div>
    `;
  }
}
UUILoaderBarElement.styles = [
  css`
      :host([hidden]) {
        transform: scaleY(0);
      }

      #bar-anim {
        -webkit-animation: bar-loading 1s infinite linear;
                animation: bar-loading 1s infinite linear;
        background: linear-gradient(
          -90deg,
          #ffffff45 0%,
          white 25%,
          transparent 100%
        );
      }

      .animate #bar-anim {
        background: linear-gradient(
          -90deg,
          currentColor 0%,
          currentColor 25%,
          transparent 100%
        );
      }

      .animate #bar {
        display: none;
      }

      #bar-container {
        width: 100%;
        height: 10px;
        position: relative;
        overflow: hidden;
      }

      #bar {
        transition: max-width 250ms ease;
      }

      #bar-background,
      #bar {
        background: currentColor;
      }

      #bar,
      #bar-anim,
      #bar-background {
        position: absolute;
        inset: 0; /* top, left, bottom and right = 0*/
        height: 100%;
      }

      #bar-background {
        opacity: 0.3;
      }

      @-webkit-keyframes bar-loading {
        0% {
          transform: scaleX(0.4);
          transform-origin: -175% 0%;
        }

        100% {
          transform-origin: 175% 0%;
          transform: scaleX(0.4);
        }
      }

      @keyframes bar-loading {
        0% {
          transform: scaleX(0.4);
          transform-origin: -175% 0%;
        }

        100% {
          transform-origin: 175% 0%;
          transform: scaleX(0.4);
        }
      }
    `
];
__decorateClass([
  property({ type: Number })
], UUILoaderBarElement.prototype, "progress", 2);
__decorateClass([
  property({ type: Number })
], UUILoaderBarElement.prototype, "animationDuration", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], UUILoaderBarElement.prototype, "hidden", 2);

export { UUILoaderBarElement };

==> uui-loader-bar-0.0.7.tgz: package/lib/uui-loader-bar.element.js <==
import { css, LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import { styleMap } from 'lit/directives/style-map.js';

var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __decorateClass = (decorators, target, key, kind) => {
  var result = kind > 1 ? void 0 : kind ? __getOwnPropDesc(target, key) : target;
  for (var i = decorators.length - 1, decorator; i >= 0; i--)
    if (decorator = decorators[i])
      result = (kind ? decorator(target, key, result) : decorator(result)) || result;
  if (kind && result)
    __defProp(target, key, result);
  return result;
};
const clamp = (num, min, max) => Math.min(Math.max(num, min), max);
class UUILoaderBarElement extends LitElement {
  constructor() {
    super(...arguments);
    this._progress = 0;
    this._animationDuration = 1;
  }
  get progress() {
    return this._progress;
  }
  set progress(newVal) {
    const oldVal = this._progress;
    this._progress = clamp(newVal, 0, 100);
    this.requestUpdate("progress", oldVal);
  }
  get animationDuration() {
    return this._animationDuration;
  }
  set animationDuration(newVal) {
    const oldVal = this._animationDuration;
    this._animationDuration = newVal >= 0 ? newVal : 1;
    this.requestUpdate("animationDuration", oldVal);
  }
  getProgressStyle() {
    return { maxWidth: `${this.progress}%` };
  }
  render() {
    return html`
      <div id="bar-container" class=${this.progress ? "" : "animate"}>
        <div
          id="bar"
          style=${this.progress ? styleMap(this.getProgressStyle()) : ""}></div>
        <div
          id="bar-anim"
          style="animation-duration: ${this.animationDuration}s"></div>
        <div id="bar-background"></div>
      </div>
    `;
  }
}
UUILoaderBarElement.styles = [
  css`
      #bar-anim {
        -webkit-animation: bar-loading 1s infinite linear;
                animation: bar-loading 1s infinite linear;
        background: linear-gradient(
          -90deg,
          #ffffff45 0%,
          white 25%,
          transparent 100%
        );
      }

      .animate #bar-anim {
        background: linear-gradient(
          -90deg,
          currentColor 0%,
          currentColor 25%,
          transparent 100%
        );
      }

      .animate #bar {
        display: none;
      }

      #bar-container {
        width: 100%;
        height: 4px;
        position: relative;
        overflow: hidden;
      }

      #bar {
        transition: max-width 250ms ease;
      }

      #bar-background,
      #bar {
        background: currentColor;
      }

      #bar,
      #bar-anim,
      #bar-background {
        position: absolute;
        inset: 0; /* top, left, bottom and right = 0*/
        height: 100%;
      }

      #bar-background {
        opacity: 0.3;
      }

      @-webkit-keyframes bar-loading {
        0% {
          transform: scaleX(0.4);
          transform-origin: -175% 0%;
        }

        100% {
          transform-origin: 175% 0%;
          transform: scaleX(0.4);
        }
      }

      @keyframes bar-loading {
        0% {
          transform: scaleX(0.4);
          transform-origin: -175% 0%;
        }

        100% {
          transform-origin: 175% 0%;
          transform: scaleX(0.4);
        }
      }
    `
];
__decorateClass([
  property({ type: Number })
], UUILoaderBarElement.prototype, "progress", 1);
__decorateClass([
  property({ type: Number })
], UUILoaderBarElement.prototype, "animationDuration", 1);

export { UUILoaderBarElement };
